# Tradescope Client

# ![tradescope](https://raw.githubusercontent.com/khulnasoft/tradescope/develop/docs/assets/tradescope_poweredby.svg)

Provides a minimal rest client for the tradescope rest api.

Please check out the [main project](https://github.com/khulnasoft/tradescope) for more information or details.
